@@ -7,11 +7,13 @@
 //! needs to be abstracted.
 use anyhow::{Context, Result, anyhow};
 
-pub use gitlab::Project;
+// pub use gitlab::Project;
 
 pub use gitlab::Gitlab as Client;
 pub use gitlab::api as api;
 pub use gitlab::api::Query;
+pub use gitlab::api::projects::Project;
+pub use gitlab::api::projects::ProjectBuilder;
 pub use gitlab::api::projects::CreateProject;
 pub use gitlab::api::projects::CreateProjectBuilder;
 
